/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005-2006 ObjectWeb, http://www.objectweb.org/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: $
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.component.framework.exception;

import java.net.URI;

import javax.xml.namespace.QName;

import org.w3c.dom.Document;

/**
 * <p>
 * All exceptions based on this exception will be transform in a SOAP Fault
 * according to the following rules:
 * <ul>
 * <li>the fault code is set with the value returned by
 * {@link DocumentException#getFaultCode()},</li>
 * <li>the fault string is set with the value returned by
 * {@link DocumentException#getMessage()},</li>
 * <li>the fault actor is set with the value returned by
 * {@link DocumentException#getFaultActor()},</li>
 * <li>the detail is set with the exception document returned by
 * {@link DocumentException#getDocument()()}.</li>
 * </ul>
 * </p>
 * 
 * @author Christophe DENEUX (Capgemini Sud)
 * 
 */
public abstract class DocumentException extends FaultException {

    public DocumentException(QName faultCode, String faultString,
            final URI faultActor) {
        super(faultCode, faultString, faultActor);
    }

    public abstract Document getDocument();
}
