/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.component.framework.interceptor.impl;

import java.util.Map;
import java.util.Set;

import org.objectweb.petals.component.framework.interceptor.Interceptor;
import org.objectweb.petals.component.framework.util.Exchange;
import org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement;

/**
 * A simple interceptor used to display interceptor values
 *
 * @author Christophe HAMERLING (chamerling) - eBM WebSourcing
 *
 */
public class InterceptorInfoInterceptor extends Interceptor {

    /*
     * (non-Javadoc)
     *
     * @see org.objectweb.petals.component.framework.interceptor.Interceptor#handleMessageAccept(org.objectweb.petals.component.framework.util.Exchange,
     *      org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement,
     *      java.util.Map)
     */
    @Override
    public void handleMessageAccept(Exchange mex,
            ServiceUnitExtensibleElement consumeProvide,
            Map<String, String> parameters) {
        System.out.println("### Intercepting message on ACCEPT");
        printInfo(mex, parameters);
    }

    /*
     * (non-Javadoc)
     *
     * @see org.objectweb.petals.component.framework.interceptor.Interceptor#handleMessageSent(org.objectweb.petals.component.framework.util.Exchange,
     *      org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement,
     *      java.util.Map)
     */
    @Override
    public void handleMessageSent(Exchange mex,
            ServiceUnitExtensibleElement consumeProvide,
            Map<String, String> parameters) {
        System.out.println("### Intercepting message on SEND");
        printInfo(mex, parameters);
    }

    /**
     *
     * @param parameters
     */
    private void printInfo(Exchange exchange,
            Map<String, String> parameters) {
        System.out.println("  Exchange ID : " + exchange.getExchangeId());
        System.out.println("  Interceptor name : " + getName());
        Set<String> keys = parameters.keySet();
        for (String key : keys) {
            System.out.println("    Parameter key='" + key + "' value='"
                    + parameters.get(key) + "'");
        }
    }
}
